@@ -18,6 +18,9 @@ cik_search <- function(company) {
   href <- paste0("https://www.sec.gov/cgi-bin/cik_lookup",
                 "?company=", URLencode(company, reserved = TRUE))
   res <- httr::GET(href)
+  if (res$status != "200") {
+    stop("Unable to reach the SEC cik lookup endpoint (https://www.sec.gov/cgi-bin/cik_lookup)")
+  }
   doc <- xml2::read_html(res, base_url = href)
 
   entries_xpath <- "//pre/a[starts-with(@href,'browse-edgar')]"
